@@ -36,7 +36,13 @@
 # define C_DEFAULT_TARGET_STACK_SIZE (128*1024)
 #endif
 #ifndef C_STACK_GROWS_DOWNWARD
-# define C_STACK_GROWS_DOWNWARD (1)
+# define C_STACK_GROWS_DOWNWARD (0)
+#endif
+#ifndef C_TARGET_MORE_LIBS
+# define C_TARGET_MORE_LIBS "-lm  "
+#endif
+#ifndef C_TARGET_MORE_STATIC_LIBS
+# define C_TARGET_MORE_STATIC_LIBS "-lm "
 #endif
 #ifndef C_TARGET_CC
 # define C_TARGET_CC "cc"
@@ -45,8 +51,20 @@
 # define C_TARGET_CXX "c++"
 #endif
 #ifndef C_TARGET_CFLAGS
-# define C_TARGET_CFLAGS ""
+# define C_TARGET_CFLAGS "-DHAVE_CHICKEN_CONFIG -O2 -pipe -I/usr/local/include -DC_ENABLE_PTABLES -DC_NO_PIC_NO_DLL"
 #endif
-#ifndef C_TARGET_LFLAGS
-# define C_TARGET_LFLAGS ""
+#ifndef C_CROSS_CHICKEN
+# define C_CROSS_CHICKEN 0
+#endif
+#ifndef C_TARGET_LIB_HOME
+# define C_TARGET_LIB_HOME "/usr/local/lib"
+#endif
+#ifndef C_TARGET_SHARE_HOME
+# define C_TARGET_SHARE_HOME "/usr/local/share"
+#endif
+#ifndef C_TARGET_INCLUDE_HOME
+# define C_TARGET_INCLUDE_HOME "/usr/local/include"
+#endif
+#ifndef C_TARGET_STATIC_LIB_HOME
+# define C_TARGET_STATIC_LIB_HOME "/usr/local/lib/lib"
 #endif
