@@ -1,6 +1,6 @@
 ;;;; chicken-more-macros.scm - More syntax extensions
 ;
-; Copyright (c) 2000-2006, Felix L. Winkelmann
+; Copyright (c) 2000-2007, Felix L. Winkelmann
 ; All rights reserved.
 ;
 ; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
@@ -86,9 +86,12 @@
        (begin
 	 (##sys#check-syntax 'receive vars 'lambda-list)
 	 (##sys#check-syntax 'receive rest '(_ . _))
-	 `(##sys#call-with-values 
-	   (lambda () ,(car rest))
-	   (lambda ,vars ,@(cdr rest)) ) ) ) ) )
+	 (if (and (pair? vars) (null? (cdr vars)))
+	     `(let ((,(car vars) ,(car rest)))
+		,@(cdr rest))
+	     `(##sys#call-with-values 
+	       (lambda () ,(car rest))
+	       (lambda ,vars ,@(cdr rest)) ) ) ) ) ) )
 
 (##sys#register-macro
  'time 
@@ -114,13 +117,15 @@
        [read read]
        [reverse reverse] )
    (lambda (filename)
-     `(begin
-	,@(with-input-from-file (##sys#resolve-include-filename filename #t)
-	    (lambda ()
-	      (do ([x (read) (read)]
-		   [xs '() (cons x xs)] )
-		  ((eof-object? x) 
-		   (reverse xs))) ) ) ) ) ) )
+     (let ((path (##sys#resolve-include-filename filename #t)))
+       (when (load-verbose) (print "; including " path " ..."))
+       `(begin
+	  ,@(with-input-from-file path
+	      (lambda ()
+		(do ([x (read) (read)]
+		     [xs '() (cons x xs)] )
+		    ((eof-object? x) 
+		     (reverse xs))) ) ) ) ) ) ) )
 
 (##sys#register-macro
  'assert
@@ -232,17 +237,21 @@
  (lambda (test . body)
    `(if ,test (##core#undefined) (begin ,@body)) ) )
 
-(let* ([map map]
-       [assign
+(let* ((map map)
+       (assign
 	(lambda (vars exp)
 	  (##sys#check-syntax 'set!-values/define-values vars '#(symbol 0))
-	  (if (null? vars)
-	      `(##sys#call-with-values (lambda () ,exp) (lambda () (##core#undefined)))
-	      (let ([aliases (map gensym vars)])
-		`(##sys#call-with-values
-		  (lambda () ,exp)
-		  (lambda ,aliases
-		    ,@(map (lambda (v a) `(##core#set! ,v ,a)) vars aliases) ) ) ) ) ) ] )
+	  (cond ((null? vars)
+		 ;; may this be simply "exp"?
+		 `(##sys#call-with-values (lambda () ,exp) (lambda () (##core#undefined))) )
+		((null? (cdr vars))
+		 `(##core#set! ,(car vars) ,exp)) 
+		(else
+		 (let ([aliases (map gensym vars)])
+		   `(##sys#call-with-values
+		     (lambda () ,exp)
+		     (lambda ,aliases
+		       ,@(map (lambda (v a) `(##core#set! ,v ,a)) vars aliases) ) ) ) ) ) ) ) )
   (##sys#register-macro 'set!-values assign)
   (##sys#register-macro 'define-values assign) )
 
@@ -284,10 +293,15 @@
        (let fold ([llists llists]
 		  [exps (map (lambda (x) (cadr x)) vbindings)]
 		  [llists2 llists2] )
-	 (if (null? llists)
-	     `(let ,(map (lambda (v) (##sys#list v (lookup v))) vars) ,@body)
-	     `(##sys#call-with-values (lambda () ,(car exps))
-				      (lambda ,(car llists2) ,(fold (cdr llists) (cdr exps) (cdr llists2))) ) ) ) ) ) ) )
+	 (cond ((null? llists)
+		`(let ,(map (lambda (v) (##sys#list v (lookup v))) vars) ,@body) )
+	       ((and (pair? (car llists2)) (null? (cdar llists2)))
+		`(let ((,(caar llists2) ,(car exps)))
+		   ,(fold (cdr llists) (cdr exps) (cdr llists2)) ) )
+	       (else
+		`(##sys#call-with-values
+		  (lambda () ,(car exps))
+		  (lambda ,(car llists2) ,(fold (cdr llists) (cdr exps) (cdr llists2))) ) ) ) ) ) ) ) )
 
 (##sys#register-macro-2
  'let*-values
@@ -606,9 +620,11 @@
 (define-macro (:optional rest default-exp)
   (let ([var (gensym)])
     `(let ((,var ,rest))
-       (cond ((null? ,var) ,default-exp)
-	     ((null? (cdr ,var)) (car ,var))
-	     (else (##core#check (##sys#error (##core#immutable '"too many optional arguments") ,var)))))))
+       (if (null? ,var) 
+	   ,default-exp
+	   (if (##core#check (null? (cdr ,var)))
+	       (car ,var)
+	       (##sys#error (##core#immutable '"too many optional arguments") ,var))))))
 
 
 ;;; (LET-OPTIONALS* args ((var1 default1) ... [rest]) body1 ...)
@@ -753,7 +769,6 @@
   (let ([vars (cdr conser)]
 	[slotnames (map car slots)] )
     `(begin
-       (define ,t ',t)
        (define ,conser
 	 (##sys#make-structure 
 	  ',t 
